@@ -20,11 +20,11 @@
  * Contributor(s):
  *   Pete Collins
  *   Brian King
+ *   Charles Manske (cmanske@netscape.com)
+ *   Neil Rashbrook (neil@parkwaycc.co.uk)
  */
 
 // Each editor window must include this file
-// Variables  shared by all dialogs:
-var editorShell;
 
 // Object to attach commonly-used widgets (all dialogs should use this)
 var gDialog = {};
@@ -52,27 +52,6 @@ var gLocation;
 // The element being edited - so AdvancedEdit can have access to it
 var globalElement;
 
-function InitEditorShell()
-{
-    // get the editor shell from the parent window
-
-  editorShell = window.opener.editorShell;
-  if (editorShell) {
-    editorShell = editorShell.QueryInterface(Components.interfaces.nsIEditorShell);
-  }
-  if (!editorShell) {
-    dump("EditorShell not found!!!\n");
-    window.close();
-    return false;
-  }
-
-  // Save as a property of the window so it can be used by child dialogs
-
-  window.editorShell = editorShell;
-
-  return true;
-}
-
 /* Validate contents of an input field 
  *
  *  inputWidget    The 'textbox' XUL element for text input of the attribute's value
@@ -469,14 +448,14 @@ function onMoreFewer()
 {
   if (SeeMore)
   {
-    gDialog.MoreSection.setAttribute("collapsed","true");
+    gDialog.MoreSection.collapsed = true;
     gDialog.MoreFewerButton.setAttribute("more","0");
     gDialog.MoreFewerButton.setAttribute("label",GetString("MoreProperties"));
     SeeMore = false;
   }
   else
   {
-    gDialog.MoreSection.removeAttribute("collapsed");
+    gDialog.MoreSection.collapsed = false;
     gDialog.MoreFewerButton.setAttribute("more","1");
     gDialog.MoreFewerButton.setAttribute("label",GetString("FewerProperties"));
     SeeMore = true;
@@ -538,8 +517,8 @@ function GetLocalFileURL(filterType)
   }
   SaveFilePickerDirectory(fp, fileType);
   
-  var ioService = GetIOService();
-  return fp.file ? ioService.getURLSpecFromFile(fp.file) : null;
+  var fileHandler = GetFileProtocolHandler();
+  return fp.file ? fileHandler.getURLSpecFromFile(fp.file) : null;
 }
 
 function GetMetaElement(name)
@@ -629,7 +608,7 @@ function CreateHTTPEquivElement(name)
 // Change "content" attribute on a META element,
 //   or delete entire element it if content is empty
 // This uses undoable editor transactions
-function SetMetaElementContent(metaElement, content, insertNew)
+function SetMetaElementContent(metaElement, content, insertNew, prepend)
 {
   if (metaElement)
   {
@@ -638,14 +617,17 @@ function SetMetaElementContent(metaElement, content, insertNew)
       if(!content || content == "")
       {
         if (!insertNew)
-          editor.deleteElement(metaElement);
+          editor.deleteNode(metaElement);
       }
       else
       {
         if (insertNew)
         {
           metaElement.setAttribute("content", content);
-          AppendHeadElement(metaElement);
+          if (prepend)
+            PrependHeadElement(metaElement);
+          else
+            AppendHeadElement(metaElement);
         }
         else
           editor.setAttribute(metaElement, "content", content);
@@ -665,6 +647,20 @@ function GetHeadElement()
   return null;
 }
 
+function PrependHeadElement(element)
+{
+  var head = GetHeadElement();
+  if (head)
+  {
+    var editor = GetCurrentEditor();
+    try {
+      // Use editor's undoable transaction
+      // Last param "true" says "don't change the selection"
+      editor.insertNode(element, head, 0, true);
+    } catch (e) {}
+  }
+}
+
 function AppendHeadElement(element)
 {
   var head = GetHeadElement();
@@ -725,7 +721,7 @@ function SetRelativeCheckbox(checkbox)
   // Mail never allows relative URLs, so hide the checkbox
   if (editor && (editor.flags & Components.interfaces.nsIPlaintextEditor.eEditorMailMask))
   {
-    checkbox.setAttribute("collapsed", "true");
+    checkbox.collapsed = true;
     return;
   }
 
@@ -1073,7 +1069,7 @@ function FillLinkMenulist(linkMenulist, headingsArray)
           linkMenulist.appendItem(text);
 
           // Save nodes in an array so we can create anchor node under it later
-          headingsArray[NamedAnchorCount++] = heading;
+          headingsArray[text] = heading;
         }
       }
     }
